@@ -32,7 +32,9 @@ def build_wheel(  # type: ignore[no-untyped-def]
         version = google.protobuf.__version__
     print(f"*** Building protobuf wheel for {version}")
     wheel_directory = os.path.abspath(wheel_directory)
-    with tempfile.TemporaryDirectory(dir=wheel_directory) as tmp_dist_dir:
+    with tempfile.TemporaryDirectory(
+        dir=os.path.expanduser("~")  # /tmp may be nonexecutable
+    ) as tmp_dist_dir:
         run_command(
             f"git clone --depth 1 --branch v{version} https://github.com/protocolbuffers/protobuf {tmp_dist_dir}/protobuf"
         )
